﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.IO;

namespace EduNetworkBuilder
{
    public partial class TranslationWindow : Form
    {
        Network myNet = null;
        string[,] LanguageChoices = { { NB.Translate("NB_NBEn"), "en" }, { NB.Translate("NB_NBFr"), "fr" } };
        string FormChosenDir = "";

        public TranslationWindow(Network ToEdit)
        {
            InitializeComponent();
            this.KeyPreview = true;
            myNet = ToEdit;

            LocalSetup();
        }

        void LocalSetup()
        {            
            cb1Language.Items.Clear();
            cb2Language.Items.Clear();

            panelTranslateFormItems.Enabled = false;

            NBSettings mySettings = NB.GetSettings();

            //See if the file we are editing has the right folder.  If so, we do not need to choose one
            FormChosenDir = mySettings.FormLastTransDir;
            if (!TryToChooseFormDir(FormChosenDir))
                TryToChooseFormDir(Path.GetDirectoryName(myNet.NetworkFilename));

            for (int i = 0; i < LanguageChoices.GetLength(0); i++)
            {
                cb1Language.Items.Add(LanguageChoices[i, 0]);
                cb2Language.Items.Add(LanguageChoices[i, 0]);
                if(mySettings.LastTrans1Lang == LanguageChoices[i, 1])
                {
                    cb1Language.SelectedItem = LanguageChoices[i, 0];
                }
                if (mySettings.LastTrans2Lang == LanguageChoices[i, 1])
                {
                    cb2Language.SelectedItem = LanguageChoices[i, 0];
                }
            }
            if (cb1Language.SelectedIndex == -1) cb1Language.SelectedIndex = 0;
            if (cb2Language.SelectedIndex == -1) cb2Language.SelectedIndex = 0;
            Icon = Properties.Resources.NBIco;
            lblStatus.Text = "";
            LanguagifyComponents();
        }

        private void LanguagifyComponents()
        {
            Text = NB.Translate("TW_Translate");
            btnSave.Text = NB.Translate("_Save");
            btnClose.Text = NB.Translate("_Done");
            tpMessageTitle.Text = NB.Translate("TW_Message");
            tpFormStuff.Text = NB.Translate("TW_Form");
        }

        private void ClosingStuff()
        {
            NBSettings mySettings = NB.GetSettings();
            for (int i = 0; i < LanguageChoices.GetLength(0); i++)
            {
                if (cb1Language.Text == LanguageChoices[i, 0])
                {
                    mySettings.LastTrans1Lang = LanguageChoices[i, 1];
                }
                if (cb2Language.Text == LanguageChoices[i, 0])
                {
                    mySettings.LastTrans2Lang = LanguageChoices[i, 1];
                }
                mySettings.FormLastTransDir = FormChosenDir;
            }
            mySettings.Save();
        }

        string CodeFromLang(string language)
        {
            for (int i = 0; i < LanguageChoices.GetLength(0); i++)
            {
                if (language == LanguageChoices[i, 0]) return LanguageChoices[i, 1];
            }
            return "";
        }

        string LangFromCode(string Code)
        {
            for (int i = 0; i < LanguageChoices.GetLength(0); i++)
            {
                if (Code == LanguageChoices[i, 1]) return LanguageChoices[i, 0];
            }
            return "";
        }

        private void btnClose_Click(object sender, EventArgs e)
        {            
            Close();
        }

        private void Save()
        {
            if (File.Exists(myNet.NetworkFilename))
            {
                myNet.Save();
                //Console.WriteLine("Saved");
                lblStatus.Text = NB.Translate("_Saved");
            }
        }

        private void TranslationWindow_KeyDown(object sender, KeyEventArgs e)
        {
            if(e.Modifiers == Keys.Control && e.KeyCode == Keys.S)
            {
                //ctrl-s was pressed
                Save();
            }
        }

        private void TranslationWindow_FormClosing(object sender, FormClosingEventArgs e)
        {
            ClosingStuff();
        }

        private void cb1Language_SelectedIndexChanged(object sender, EventArgs e)
        {
            string What = CodeFromLang(cb1Language.Text);
            if (What != "")
            {
                tb1Message.Text = myNet.NetMessage.GetText(What);
                tb1Title.Text = myNet.NetTitle.GetText(What);
                tb1URL.Text = myNet.NetURL.GetText(What);
            }
        }

        private void cb2Language_SelectedIndexChanged(object sender, EventArgs e)
        {
            string What = CodeFromLang(cb2Language.Text);
            if (What != "")
            {
                tb2Message.Text = myNet.NetMessage.GetText(What);
                tb2Title.Text = myNet.NetTitle.GetText(What);
                tb2URL.Text = myNet.NetURL.GetText(What);
            }
        }

        void RefreshContents()
        {
            cb1Language_SelectedIndexChanged(null, EventArgs.Empty);
            cb2Language_SelectedIndexChanged(null, EventArgs.Empty);
            lblStatus.Text = "";
        }

        private void tb1Message_Leave(object sender, EventArgs e)
        {
            string What = CodeFromLang(cb1Language.Text);
            if (What != "")
            {
                myNet.NetMessage.ChangeText(What,tb1Message.Text);
            }
            RefreshContents();
        }

        private void tb2Message_Leave(object sender, EventArgs e)
        {
            string What = CodeFromLang(cb2Language.Text);
            if (What != "")
            {
                myNet.NetMessage.ChangeText(What, tb2Message.Text);
            }
            RefreshContents();
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            Save();
        }

        private void tb1Title_Leave(object sender, EventArgs e)
        {
            string What = CodeFromLang(cb1Language.Text);
            if (What != "")
            {
                myNet.NetTitle.ChangeText(What, tb1Title.Text);
            }
            RefreshContents();
        }

        private void tb2Title_Leave(object sender, EventArgs e)
        {
            string What = CodeFromLang(cb2Language.Text);
            if (What != "")
            {
                myNet.NetTitle.ChangeText(What, tb2Title.Text);
            }
            RefreshContents();
        }

        private void tb1URL_Leave(object sender, EventArgs e)
        {
            string What = CodeFromLang(cb1Language.Text);
            if (What != "")
            {
                myNet.NetURL.ChangeText(What, tb1URL.Text);
            }
            RefreshContents();
        }

        private void tb2URL_Leave(object sender, EventArgs e)
        {
            string What = CodeFromLang(cb2Language.Text);
            if (What != "")
            {
                myNet.NetURL.ChangeText(What, tb2URL.Text);
            }
            RefreshContents();
        }




        //**********************************************************************//
        //******************* Form Translation Things **************************//
        //**********************************************************************//
        bool TryToChooseFormDir(string Choice)
        {
            string targetfile = "edustrings.resx";
            if (Choice == null || Choice == "") return false;
            //We want to have a file named edustrings.resx there

            //There may be other files: edustrings.fr.resx
            //If these exist, we are OK.  Otherwise, see if there is a "languages" dir and try that if it does exist
            string toCheck = Path.GetFileName(Choice).ToLower();
            if (File.Exists(Choice))
                if (toCheck == targetfile)
                {
                    FormChosenDir = Path.GetDirectoryName(Choice);
                    panelTranslateFormItems.Enabled = true;
                    lblFormDir.Text = "Dir: " + FormChosenDir;
                    lblFormDir.AutoSize = true;
                    lblFormDir.MaximumSize = new Size(250, 200);
                    return true;
                }
                
            if(Directory.Exists(Choice))
            {
                //It is a directory.  See if it has the correct file in it.
                if (TryToChooseFormDir(Path.Combine(Choice, targetfile)))
                {
                    return true; //It was successful
                }
                //If we get here, it did not have the file.  See if there is a "languages" directory
                if (TryToChooseFormDir(Path.Combine(Choice, "languages", targetfile))) 
                {
                    return true; //It was successful
                }
            }
            return false;
        }

        private void btnChooseDir_Click(object sender, EventArgs e)
        {
            string startingDir = FormChosenDir;
            if (FormChosenDir == "" && File.Exists(myNet.NetworkFilename))
                startingDir = Path.GetDirectoryName(myNet.NetworkFilename);
            //Prompt for a directory.

            OpenFileDialog ofd = NB.SelectDirectoryDialog("Directory with language files", startingDir);
            if(ofd.FileName != "")
            {
                //try to see if the chosen filename has appropriate files.  We need the English, at least
                if(!TryToChooseFormDir(Path.GetDirectoryName(ofd.FileName)))
                {
                    MessageBox.Show("Invalid Directory.");
                }
            }
        }
    }
}
